<?php
ini_set('memory_limit', '-1');
class BuscarcitasF extends CI_Controller
{
	
	function __construct(){
		parent::__construct();
		
		$this->load->model('myagenda/franquiciatario/agendaF_model');
		$this->load->library(array('session','form_validation'));
	}

	public function index(){
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '3')
		{
			redirect(base_url().'acceso/acceso');
		} else {

			$data['Franquicias']=$this->agendaF_model->BuscarFranquicia(); 
		 	foreach ($data['Franquicias'] as $i => $Franquicias) 
			$this->db->select('*');
			$this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
			$this->db->where('Franquicias_IdFranquicias',$i);
			$data['consulta']=$this->db->get('agenda')->result();

		$this->load->view('layout/headerFran');
		$this->load->view('layout/menuFranquicia');
		$dato['ReCabina']=$this->agendaF_model->BuscarCabina();
		$this->load->view('agenda/franquiciatario/buscarporcabinaF_view', $data);
		$this->load->view('layout/footer');
		}
	}

	public function buscarporcabina(){ 
		$filtro = $this->input->post('codecabina');
		$r = $this->agendaF_model->getEventos($filtro);
		
		echo json_encode($r);
	}


	public function depurarinfo($r){
		$coloresCabina= array(
		            "FACIAL"  =>  '#37579D',
		            "FACIAL 2"  =>  '#D8907C',
		            "CORPORAL"  =>  '#C0473E',
		            "CORPORAL 2"  =>  '#BE304A',
		            "RELAJANTES/MASAJES"  =>  '#47A3A0',
		            "CAVITACION"  =>  '#DFA130',
		            "IPL/E-LIGHT"  =>  '#76B9E5',
		            "PESTAÑAS"  =>  '#1E7999',
		            "SAUNA"  =>  '#EAC595',
		            "SAUNA 2" =>  '#4C418E',
		            "ADICIONAL" =>  '#902456',
		            "CAPSULA INFRAROJA" =>  '#BD2367',
		            "UÑAS 1" =>  '#A71929',
		            "UÑAS 2" =>  '#7890C4',
		            "UÑAS 3" =>  '#9DAB2D',

		        );
		
		foreach ($r as $item) 
		{ 
		        
				$tratamiento=$this->agendaF_model->nombreTratamiento($item->servicio, $item->promociones);
		        $datosProcesados[] = array(
		            "start"      =>  $item->start."T". $item->hoi,
		            "end"        =>  $item->start."T". $item->hof,
		            "id"         =>  $item->id,
		            "title" 	 =>  $item->clientes,
					"cabina"     =>  $item->cabina,
					"idCliente"   =>  $item->idC,
		            "clientes"   =>  $item->clientes,
		            "categoria"  =>  $item->categoria,
		            "promociones"=>  $item->promociones,
		            "servicio"   =>  $item->servicio,
		            "hoi"      =>  $item->hoi,
		            "hof"      =>  $item->hof,
		            "est"      =>  $item->est,
		            "obs"      =>  $item->obs,
		            "usu"      =>  $item->usu,
		            "fecha"    =>  $item->fecha,
					"nombreCabina"    =>  $item->NombreCabina,
					"descripcion"  =>  $tratamiento."\r\n".$item->clientes."\r\n".$item->Celular,
		            "color"    =>  $coloresCabina[(String)$item->NombreCabina]

		        );
		}
		return $datosProcesados;
	}

	public function buscarporcliente (){ 
		$cliente = $this->input->post('name');
		$r = $this->agendaF_model->BuscarPorNombreCliente($cliente);
		$r2 = $this->agendaF_model->personalIdExistentes();
		$response = [];
		//$i=0;
		foreach ($r as $item) {
			foreach ($r2 as $item2) {
				//echo $item2->IdUsuarios."*****".$item->Usuarios_IdUsuarios."<br><br>".$i;
				if ($item2->IdUsuarios == $item->Usuarios_IdUsuarios) {
					//$i++;
					//echo $item2->IdUsuarios."*****".$item->Usuarios_IdUsuarios."<br><br>".$i;
					array_push($response, $item);
				}				
			}
		}
		/*echo "<br><br>--0--<br><br>";
		echo json_encode(count($r));
		echo "<br><br>--1--<br><br>";
		echo json_encode(count($r2));
		echo "<br><br>--2--<br><br>";
		echo json_encode(count($response));
		echo "<br><br>--3--<br><br>";*/
		echo json_encode($response);
		return json_encode($response);
	}


	// public function getEventos(){
	// 	$r = $this->agendaF_model->getEventos();
	// 	echo json_encode($r);
	


	// 	}
	

	// public function getEventos1(){
	// 	$r = $this->agendaF_model->getEventos();
	// 	echo json_encode($r);
	// }

	// // public function updEvento(){
	// // 	$param['IdAgenda'] = $this->input->post('IdAgenda');
	// // 	$param['Fecha'] = $this->input->post('Fecha');
	// // 	//$param['fecfin'] = $this->input->post('fecfin');

	// // 	$r = $this->agendaF_model->updEvento($param);

	// // 	echo $r;
	// // }

	// public function deleteEvento(){

	// 	$id = $this->input->post('IdAgenda');
	// 	$r = $this->agendaF_model->deleteEvento($id);
	// 	echo $r;
	// }




// 	public function agregar(){
// 		if($this->session->userdata('Rol_IdRol')==FALSE || 
// 			$this->session->userdata('Rol_IdRol') == '1'|| 
// 			$this->session->userdata('Rol_IdRol') == '3')
// 		{
// 			redirect(base_url().'acceso/acceso');
// 		} else {
// 		$this->load->view('layout/headerFran');
// 		$this->load->view('layout/menuFranquicia');
// 		$datos['ReCabina']=$this->agendaF_model->BuscarCabina();
// 	    $datos['ReFranquicia']=$this->agendaF_model->BuscarFranquicia();
// 	    $datos['ReUsuario']=$this->agendaF_model->BuscarUsuario();
// 	    $datos['ReCategoria']=$this->agendaF_model->BuscarCategoria();
// 		// // $datos['ReCliente']=$this->agendaF_model->BuscarCliente();
// 		// $datos['ReServicios']=$this->agendaF_model->BuscarServicios();
// 		// $datos['RePromocionesInstitucionales']=$this->agendaF_model->BuscarPromocionesinstitucionales();
// 		// $datos['RePromocionesLocales']=$this->agendaF_model->BuscarPromocionesLocales();
// 		 $datos['ReEstatusCita']=$this->agendaF_model->BuscarEstatusCita();
// 		$this->load->view('agenda/franquiciatario/agregarcitaF_view', $datos);
// 		$this->load->view('layout/footer');

	
// 	}
// }

// 	public function citasCanceladas(){
// 		if($this->session->userdata('Rol_IdRol')==FALSE || 
// 			$this->session->userdata('Rol_IdRol') == '1'|| 
// 			$this->session->userdata('Rol_IdRol') == '3')
// 		{
// 			redirect(base_url().'acceso/acceso');
// 		} else {
// 		 $data['Franquicias']=$this->agendaF_model->BuscarFranquicia();
// 		foreach ($data['Franquicias'] as $i => $Franquicias) 
// 		$this->db->select('*');
// 		//$this->db->from('agenda');
// 		$this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
// 	    $this->db->join('categoria','Categoria_IdCategoria = IdCategoria','inner');
// 	    $this->db->join('cabina','Cabina_IdCabina = IdCabina','inner');
//         $this->db->join('clientes','Clientes_IdClientes = IdClientes','inner');
// 		$this->db->where('IdFranquicias',$i);
// 		$this->db->where('estatuscitas_IdEstatusCita = 3');
// 		$data['consulta']=$this->db->get('agenda')->result();
// 		$this->load->view('layout/headerFran');
// 		$this->load->view('layout/menuFranquicia');
// 		$this->load->view('agenda/franquiciatario/citasCanceladasF_view', $data);
// 		$this->load->view('layout/footer');

	
// 	}
// }
 // //Esta funcion se uiliza para la vista agenda agregarCita_view
	// public function guardar(){

		

	// 	$parametro['Clientes_IdClientes']= $this->input->post('idcliente');
	// 	$parametro['Categoria_IdCategoria']= $this->input->post('txtcategoria');
	// 	$parametro['ServiciosFranquicias_IdServiciosFranquicias']= $this->input->post('idservi');
	// 	//$parametro['ServiciosFranquicias_IdServiciosFranquicias']= $this->input->post('idserviGM');
	// 	$parametro['Promociones_IdPromociones']= $this->input->post('idpromo');
	//    // $parametro['Promociones_IdPromociones']= $this->input->post('idpromoInst');
	// 	$parametro['Fecha']= $this->input->post('txtfecha');
	// 	$parametro['HoraInicio']= $this->input->post('txthorai');
	// 	$parametro['HoraFin']= $this->input->post('txthoraf');
	// 	$parametro['Cabina_IdCabina']= $this->input->post('txt_cabina');
	// 	$parametro['estatuscitas_IdEstatusCita']= $this->input->post('txtstatus');
	// 	$parametro['Observaciones']= $this->input->post('txt_observaciones');
	// 	$parametro['Franquicias_IdFranquicias']= $this->input->post('txt_franquicia');
	// 	$parametro['Usuarios_IdUsuarios']= $this->input->post('txtusuario');
	


	// 	$this->agendaF_model->guardar($parametro);

	// 	redirect('agenda/franquiciatario/listacitasF', 'refresh');

	// }






	public function updEvento2(){
		$param['ide'] = $this->input->post('ide');
		$param['nome'] = $this->input->post('nome');
		$param['clientes'] = $this->input->post('clientes');
		$param['categoria'] = $this->input->post('categoria');
		$param['promociones'] = $this->input->post('promociones');
		$param['servicios'] = $this->input->post('servicios');
		$param['fecha'] = $this->input->post('fecha');
		$param['horai'] = $this->input->post('horai');
		$param['horaf'] = $this->input->post('horaf');
		$param['estado'] = $this->input->post('estado');
		$param['observaciones'] = $this->input->post('observaciones');
		$param['usuario'] = $this->input->post('usuario');

		//$r = $this->agendaF_model->updEvento2($param);

		//echo $r;

		$this->agendaF_model->updEvento2($param);

	 	redirect('agenda/franquiciatario/listacitasF', 'refresh');
	}


}